Welcome to S3_analyst's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2
   :glob:


   FromMakefile/README_coveo.md
   FromMakefile/README.md
   installation
   usage
   module
   FromMakefile/CONTRIBUTING.md
   FromMakefile/AUTHORS.md
   FromMakefile/BIBLIOGRAPHY.md
   FromMakefile/HISTORY.md

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
